/**
 * @copyright Cube Dev, Inc.
 * @license Apache-2.0
 * @fileoverview The `MongoBIDriver` and related types declaration.
 */
import { Connection, ConnectionOptions } from 'mysql2';
import { Pool } from 'generic-pool';
import { BaseDriver, DownloadQueryResultsOptions, DownloadQueryResultsResult, DriverInterface, StreamOptions } from '@cubejs-backend/base-driver';
export interface MongoBIDriverConfiguration extends ConnectionOptions {
    storeTimezone?: string;
}
/**
 * MongoBI driver class.
 */
export declare class MongoBIDriver extends BaseDriver implements DriverInterface {
    /**
     * Returns default concurrency value.
     */
    static getDefaultConcurrency(): number;
    protected readonly config: MongoBIDriverConfiguration;
    protected readonly pool: Pool<Connection>;
    /**
     * Class constructor.
     */
    constructor(config?: MongoBIDriverConfiguration & {
        /**
         * Data source name.
         */
        dataSource?: string;
        /**
         * Max pool size value for the [cube]<-->[db] pool.
         */
        maxPoolSize?: number;
        /**
         * Time to wait for a response from a connection after validation
         * request before determining it as not valid. Default - 10000 ms.
         */
        testConnectionTimeout?: number;
    });
    protected withConnection<T>(fn: (conn: Connection) => Promise<T>): Promise<T>;
    testConnection(): Promise<void>;
    query<R = unknown>(sql: string, values: unknown[]): Promise<R[]>;
    protected prepareConnection(conn: Connection): Promise<void>;
    stream(query: string, values: unknown[], options: StreamOptions): Promise<any>;
    downloadQueryResults(query: string, values: unknown[], options: DownloadQueryResultsOptions): Promise<DownloadQueryResultsResult>;
    release(): Promise<void>;
    informationSchemaQuery(): string;
    quoteIdentifier(identifier: string): string;
    readOnly(): boolean;
}
//# sourceMappingURL=MongoBIDriver.d.ts.map